import httpx
import pydantic
import datetime


class HttpResponse(pydantic.BaseModel):
    url: str
    status_code: int
    response_body: str
    retrieved_at: datetime.datetime = pydantic.Field(
        default_factory=datetime.datetime.now
    )


class HttpRequest:
    def __init__(self, beaker: str, field: str):
        self.beaker = beaker
        self.field = field

    async def __call__(self, item) -> HttpResponse:
        bkr = getattr(item, self.beaker)
        url = getattr(bkr, self.field)

        async with httpx.AsyncClient() as client:
            response = await client.get(url)

        return HttpResponse(
            url=url,
            status_code=response.status_code,
            response_body=response.text,
        )
